@@ -1,8 +1,8 @@
-from .core import generate
+from wombopy.core import generate
 
 
 __app_name__ = "wombopy"
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 (
     SUCCESS,
